@@ -12,7 +12,7 @@ use Scalar::Util 'weaken';
 use URI;
 use URI::db;
 
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 
 has 'auto_migrate';
 has database_class  => 'Mojo::SQLite::Database';
@@ -166,19 +166,6 @@ Mojo::SQLite - A tiny Mojolicious wrapper for SQLite
   # Select all rows
   say $_->{name} for $db->query('select * from names')->hashes->each;
 
-  # Send and receive notifications non-blocking
-  $sql->pubsub->listen(foo => sub {
-    my ($pubsub, $payload) = @_;
-    say "foo: $payload";
-    $pubsub->notify(bar => $payload);
-  });
-  $sql->pubsub->listen(bar => sub {
-    my ($pubsub, $payload) = @_;
-    say "bar: $payload";
-  });
-  $sql->pubsub->notify(foo => 'SQLite rocks!');
-  Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
-
 =head1 DESCRIPTION
 
 L<Mojo::SQLite> is a tiny wrapper around L<DBD::SQLite> that makes
@@ -322,20 +309,7 @@ options.
 
 =head2 pubsub
 
-  my $pubsub = $sql->pubsub;
-  $sql       = $sql->pubsub(Mojo::SQLite::PubSub->new);
-
-L<Mojo::SQLite::PubSub> object you can use to send and receive notifications
-very efficiently, by sharing a single database connection with many consumers.
-
-  # Subscribe to a channel
-  $sql->pubsub->listen(news => sub {
-    my ($pubsub, $payload) = @_;
-    say "Received: $payload";
-  });
-
-  # Notify a channel
-  $sql->pubsub->notify(news => 'SQLite rocks!');
+This attribute is L<DEPRECATED|Mojo::SQLite::PubSub/"DESCRIPTION">.
 
 =head1 METHODS
 
@@ -455,8 +429,6 @@ This is the class hierarchy of the L<Mojo::SQLite> distribution.
 
 =item * L<Mojo::SQLite::Migrations>
 
-=item * L<Mojo::SQLite::PubSub>
-
 =item * L<Mojo::SQLite::Results>
 
 =item * L<Mojo::SQLite::Transaction>
