@@ -8,16 +8,20 @@ use Mojo::IOLoop;
 use Mojo::JSON 'to_json';
 use Mojo::SQLite::Results;
 use Mojo::SQLite::Transaction;
+use Mojo::Util 'deprecated';
 use Scalar::Util 'weaken';
 
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 
 our @CARP_NOT = qw(Mojo::SQLite::Migrations);
 
 use constant DEBUG => $ENV{MOJO_PUBSUB_DEBUG} || 0;
 
 has [qw(dbh sqlite)];
-has notification_poll_interval => 0.5;
+has notification_poll_interval => sub {
+  deprecated 'The notification_poll_interval attribute is deprecated and should no longer be used';
+  return 0.5;
+};
 has results_class              => 'Mojo::SQLite::Results';
 
 sub new {
@@ -55,11 +59,18 @@ sub disconnect {
   $self->dbh->disconnect;
 }
 
-sub is_listening { !!keys %{shift->{listen} || {}} }
+our $_QUERY_NOTIFICATIONS;
+
+sub is_listening {
+  deprecated 'The is_listening method is deprecated and should no longer be used' unless $_QUERY_NOTIFICATIONS;
+  return !!keys %{shift->{listen} || {}};
+}
 
 sub listen {
   my ($self, $name) = @_;
 
+  deprecated 'The listen method is deprecated and should no longer be used';
+
   warn qq{$self listening on channel "$name"\n} if DEBUG;
   $self->{listen}{$name}++;
   $self->_init_pubsub;
@@ -73,6 +84,8 @@ sub listen {
 sub notify {
   my ($self, $name, $payload) = @_;
 
+  deprecated 'The notify method is deprecated and should no longer be used';
+
   $payload //= '';
   warn qq{$self sending notification on channel "$name": $payload\n} if DEBUG;
   $self->_init_pubsub;
@@ -119,6 +132,7 @@ sub query {
   my $results = defined $sth ? $self->results_class->new(sth => $sth) : undef;
   $results->{last_insert_id} = $dbh->{private_mojo_last_insert_id} if defined $results;
   unless ($cb) {
+    local $_QUERY_NOTIFICATIONS = 1; # no deprecated message
     $self->_notifications;
     return $results;
   }
@@ -137,6 +151,8 @@ sub tables {
 sub unlisten {
   my ($self, $name) = @_;
 
+  deprecated 'The unlisten method is deprecated and should no longer be used';
+
   warn qq{$self is no longer listening on channel "$name"\n} if DEBUG;
   my $dbh = $self->dbh;
   if ($name eq '*') {
@@ -316,11 +332,7 @@ L<DBD::SQLite> database handle used for all queries.
 
 =head2 notification_poll_interval
 
-  my $interval = $db->notification_poll_interval;
-  $db          = $db->notification_poll_interval(1);
-
-Interval in seconds to poll for notifications from L</"notify">, defaults to
-C<0.5>.
+This attribute is L<DEPRECATED|Mojo::SQLite::PubSub/"DESCRIPTION">.
 
 =head2 results_class
 
@@ -381,23 +393,15 @@ Disconnect L</"dbh"> and prevent it from getting reused.
 
 =head2 is_listening
 
-  my $bool = $db->is_listening;
-
-Check if L</"dbh"> is listening for notifications.
+This method is L<DEPRECATED|Mojo::SQLite::PubSub/"DESCRIPTION">.
 
 =head2 listen
 
-  $db = $db->listen('foo');
-
-Subscribe to a channel and receive L</"notification"> events when the
-L<Mojo::IOLoop> event loop is running.
+This method is L<DEPRECATED|Mojo::SQLite::PubSub/"DESCRIPTION">.
 
 =head2 notify
 
-  $db = $db->notify('foo');
-  $db = $db->notify(foo => 'bar');
-
-Notify a channel.
+This method is L<DEPRECATED|Mojo::SQLite::PubSub/"DESCRIPTION">.
 
 =head2 ping
 
@@ -453,17 +457,7 @@ L<attached databases|http://sqlite.org/lang_attach.html>.
 
 =head2 unlisten
 
-  $db = $db->unlisten('foo');
-  $db = $db->unlisten('*');
-
-Unsubscribe from a channel, C<*> can be used to unsubscribe from all channels.
-
-=head1 DEBUGGING
-
-You can set the C<MOJO_PUBSUB_DEBUG> environment variable to get some advanced
-diagnostics information printed to C<STDERR>.
-
-  MOJO_PUBSUB_DEBUG=1
+This method is L<DEPRECATED|Mojo::SQLite::PubSub/"DESCRIPTION">.
 
 =head1 BUGS
 
